==> haskell-recaptcha-0.1.0.4-348-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-FABCuFRrHwq6yOW79cbcEF
key:                  recaptcha-0.1.0.4-FABCuFRrHwq6yOW79cbcEF
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  1fe5cd842b57276f39e5b01cdc36a4ee
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-FABCuFRrHwq6yOW79cbcEF
depends:
    HTTP-4000.4.1-5kdkKw0IJSY3CDLJxbc1mu base-4.17.2.1
    network-3.1.4.0-GdpHxCm9XS6F665gL00mHk
    network-uri-2.6.4.2-EJq2qAYdDkaFqs6P7Upy96 xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recaptcha-0.1.0.4-349-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-GRf8imPQjGO8MiobPUVrzy
key:                  recaptcha-0.1.0.4-GRf8imPQjGO8MiobPUVrzy
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  a4f63230bcd531b97d913858363aa4d2
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-GRf8imPQjGO8MiobPUVrzy
depends:
    HTTP-4000.4.1-9tyVpS4yTJaKO3RlPJnV6e base-4.17.2.1
    network-3.1.4.0-9G0x2c0R6cS5Adtb7MLWUj
    network-uri-2.6.4.2-3JXfaFN99ue5xMdSDFu2sO xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
